==> spip_3.0.20.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vas a suprimir todas las firmas de esta recolección. ¿Estás seguro que quieres continuar?',
	'aucune_signature' => 'Ninguna firma',

	// B
	'bouton_checkbox_envoi_message' => 'posibilidad de enviar un mensaje',
	'bouton_checkbox_indiquer_site' => 'indicar obligatoriamente un sitio web?',
	'bouton_checkbox_signature_unique_email' => 'una sola firma por dirección e-mail',
	'bouton_checkbox_signature_unique_site' => 'una sola firma por sitio web',

	// F
	'filtre' => 'Filtro:',
	'form_pet_adresse_site' => 'Dirección URL de tu sitio',
	'form_pet_aucune_signature' => 'Ninguna firma corresponde a este código...',
	'form_pet_confirmation' => 'Ratifica tu firma: ',
	'form_pet_deja_signe' => 'Ya has firmado este texto.',
	'form_pet_envoi_mail_confirmation' => 'Se acaba de enviar un mensaje de confirmación a @email@. Tienes que ingresar a la dirección web que contiene ese mensaje para validar tu firma.',
	'form_pet_mail_confirmation' => 'Hola,

Has solicitado añadir tu firma a:
@titre@.

Has proporcionado la siguiente información:

    Nombre: @nom_email@
    Sitio: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para confirmar tu firma, debes ingresar a
la dirección web indicada a continuación (de lo contrario, tu firma
no podrá ser tomada en cuenta):

    @url@


Gracias por tu participación
',
	'form_pet_message_commentaire' => '¿Un mensaje? ¿un comentario?',
	'form_pet_nom_site2' => 'Nombre de tu sitio web',
	'form_pet_probleme_liens' => 'Ingresa nuevamente tu mensaje, quitando los enlaces hypertexto.',
	'form_pet_probleme_technique' => 'Problema técnico, las firmas están temporalmente suspendidas.',
	'form_pet_signature_validee' => 'Tu firma está validada. ¡Gracias!',
	'form_pet_site_deja_enregistre' => 'Este sitio ya está registrado',
	'form_pet_url_invalide' => 'La URL que has indicado no es válida.',
	'form_pet_votre_email' => 'Tu dirección de correo electrónico',
	'form_pet_votre_nom' => 'Tu nombre',
	'form_pet_votre_site' => 'Si tienes un sitio web, puedes indicarlo a continuación',

	// I
	'icone_relancer_signataire' => 'Recordatorio al quién firma',
	'icone_relancer_signataires' => 'Recordatorio a quienes firman',
	'icone_suivi_petitions' => 'Seguir/gestionar las recolecciones de firmas',
	'icone_supprimer_signature' => 'Suprimir esta firma',
	'icone_supprimer_signatures' => 'Suprimir las firmas',
	'icone_valider_signature' => 'Validar esta firma',
	'icone_valider_signatures' => 'Validar las firmas',
	'info_adresse_email' => 'Dirección de correo electrónico:',
	'info_fonctionnement_petition' => 'Funcionamiento de la recolección de firmas:',
	'info_signature_supprimee' => 'Firma eliminada',
	'info_signature_supprimee_erreur' => 'Error: este código de eliminación no  corresponde a ninguna firma',
	'info_site_web' => 'SITIO WEB:',
	'info_texte_message' => 'Texto de tu mensaje:',

	// L
	'lien_reponse_article' => 'Respuesta al artículo',

	// N
	'nombre_signatures' => '@nb@ firmas',

	// S
	'sans_nom' => 'Anónimo',
	'signatures_article' => 'Firmas del artículo:',
	'signatures_aucune' => 'Ninguna',
	'signatures_meme_auteur' => 'Las firmas del mismo autor',
	'signatures_meme_site' => 'Las firmas con el mismo sitio',
	'signatures_poubelle' => 'Suprimidos',
	'signatures_prop' => 'En espera',
	'signatures_publie' => 'Confirmados',
	'signatures_recherche_label' => 'Buscar firmas:',
	'signatures_selection' => 'Seleccionar las firmas:',
	'signatures_toutes' => 'Tiodas',
	'statut_poubelle' => 'Suprimir',
	'statut_prop' => 'En espera de validación',
	'statut_publie' => 'Confirmada',

	// T
	'texte_descriptif_petition' => 'Descriptivo de la recolección de firmas',
	'titre_page_controle_petition' => 'Seguimiento de las firmas',
	'titre_petition' => 'Recolección de firmas',
	'titre_petitions' => 'Recolección de firmas',
	'titre_selection_action' => 'Sélección',
	'titre_signatures_attente' => 'Firmas a la espera de validación',
	'titre_signatures_publie' => 'Firmas confirmadas',
	'titre_suivi_petition' => 'Seguimiento de las recolecciones de firmas',
	'tout_voir' => 'Ver todas las firmas',

	// U
	'une_signature' => '1 firmas',

	// V
	'voir_signatures_objet' => 'Ver las firmas'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vas a suprimir todas las firmas de esta recolección. ¿Estás seguro que quieres continuar?',
	'aucune_signature' => 'Ninguna firma',

	// B
	'bouton_checkbox_envoi_message' => 'posibilidad de enviar un mensaje',
	'bouton_checkbox_indiquer_site' => 'indicar obligatoriamente un sitio web?',
	'bouton_checkbox_signature_unique_email' => 'una sola firma por dirección e-mail',
	'bouton_checkbox_signature_unique_site' => 'una sola firma por sitio web',
	'bouton_radio_activer_petition' => 'Activar la petición',
	'bouton_radio_pas_petition' => 'Sin petición',
	'bouton_radio_petition_activee' => 'Petición activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la petición',

	// F
	'filtre' => 'Filtro:',
	'form_pet_adresse_site' => 'Dirección URL de tu sitio',
	'form_pet_aucune_signature' => 'Ninguna firma corresponde a este código...',
	'form_pet_confirmation' => 'Ratifica tu firma: ',
	'form_pet_deja_signe' => 'Ya has firmado este texto.',
	'form_pet_envoi_mail_confirmation' => 'Se acaba de enviar un mensaje de confirmación a @email@. Tienes que ingresar a la dirección web que contiene ese mensaje para validar tu firma.',
	'form_pet_mail_confirmation' => 'Hola,

Has solicitado añadir tu firma a:
@titre@.

Has proporcionado la siguiente información:

    Nombre: @nom_email@
    Sitio: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para confirmar tu firma, debes ingresar a
la dirección web indicada a continuación (de lo contrario, tu firma
no podrá ser tomada en cuenta):

    @url@


Gracias por tu participación
',
	'form_pet_message_commentaire' => '¿Un mensaje? ¿un comentario?',
	'form_pet_nom_site2' => 'Nombre de tu sitio web',
	'form_pet_probleme_liens' => 'Ingresa nuevamente tu mensaje, quitando los enlaces hypertexto.',
	'form_pet_probleme_technique' => 'Problema técnico, las firmas están temporalmente suspendidas.',
	'form_pet_signature_validee' => 'Tu firma está validada. ¡Gracias!',
	'form_pet_site_deja_enregistre' => 'Este sitio ya está registrado',
	'form_pet_url_invalide' => 'La URL que has indicado no es válida.',
	'form_pet_votre_email' => 'Tu dirección de correo electrónico',
	'form_pet_votre_nom' => 'Tu nombre',
	'form_pet_votre_site' => 'Si tienes un sitio web, puedes indicarlo a continuación',

	// I
	'icone_relancer_signataire' => 'Recordatorio al quién firma',
	'icone_relancer_signataires' => 'Recordatorio a quienes firman',
	'icone_suivi_petitions' => 'Seguir/gestionar las recolecciones de firmas',
	'icone_supprimer_signature' => 'Suprimir esta firma',
	'icone_supprimer_signatures' => 'Suprimir las firmas',
	'icone_valider_signature' => 'Validar esta firma',
	'icone_valider_signatures' => 'Validar las firmas',
	'info_adresse_email' => 'Dirección de correo electrónico:',
	'info_fonctionnement_petition' => 'Funcionamiento de la recolección de firmas:',
	'info_signature_supprimee' => 'Firma eliminada',
	'info_signature_supprimee_erreur' => 'Error: este código de eliminación no  corresponde a ninguna firma',
	'info_site_web' => 'SITIO WEB:',
	'info_texte_message' => 'Texto de tu mensaje:',

	// L
	'lien_reponse_article' => 'Respuesta al artículo',

	// N
	'nombre_signatures' => '@nb@ firmas',

	// S
	'sans_nom' => 'Anónimo',
	'signatures_article' => 'Firmas del artículo:',
	'signatures_aucune' => 'Ninguna',
	'signatures_meme_auteur' => 'Las firmas del mismo autor',
	'signatures_meme_site' => 'Las firmas con el mismo sitio',
	'signatures_poubelle' => 'Suprimidos',
	'signatures_prop' => 'En espera',
	'signatures_publie' => 'Confirmados',
	'signatures_recherche_label' => 'Buscar firmas:',
	'signatures_selection' => 'Seleccionar las firmas:',
	'signatures_toutes' => 'Tiodas',
	'statut_poubelle' => 'Suprimir',
	'statut_prop' => 'En espera de validación',
	'statut_publie' => 'Confirmada',

	// T
	'texte_descriptif_petition' => 'Descriptivo de la recolección de firmas',
	'titre_page_controle_petition' => 'Seguimiento de las firmas',
	'titre_petition' => 'Recolección de firmas',
	'titre_petitions' => 'Recolección de firmas',
	'titre_selection_action' => 'Sélección',
	'titre_signatures_attente' => 'Firmas a la espera de validación',
	'titre_signatures_publie' => 'Firmas confirmadas',
	'titre_suivi_petition' => 'Seguimiento de las recolecciones de firmas',
	'tout_voir' => 'Ver todas las firmas',

	// U
	'une_signature' => '1 firmas',

	// V
	'voir_signatures_objet' => 'Ver las firmas'
);

?>
